@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: chk_ff_2836.sh 330 2011-06-10 13:32:10Z gbc $
+# $Id: chk_ff_2836.sh 870 2013-10-07 18:21:50Z rjc $
 #
 # canonical test suite for fourfit
 #
@@ -28,11 +28,18 @@ fourfit -pt -b AE:X \\ && echo \
 	$DATADIR/2836/scan001/2145+067.olomfh
 ) 2>/dev/null 1>&2
 
-set -- `ls -s ff-2836.ps` 0 no-such-file
-$verb && echo $@
+# pluck out line containing the snr and parse it
+line=$(grep '7570 9653' ./ff-2836.ps)
 
-# did we make a plot?
-[ $1 -ge 76 ] && rm -f ./cf2836
+IFS='()'
+read a snr b <<<"$line"
+
+# snr bounds
+low=139.1
+high=140.1
+aok=$(echo "$snr>$low && $snr<$high" | bc)
+
+[ $aok -gt 0 ]
 
 #
 # eof
