@@ -76,6 +76,7 @@ create_fsm ()
     fsm_table (BLOCK_INTERIOR,	  INT_PARAM,	     SAVE_TOKEN_NUM, NEED_INT);
     fsm_table (BLOCK_INTERIOR,	  FLOAT_PARAM,       SAVE_TOKEN_NUM, NEED_FLOAT);
     fsm_table (BLOCK_INTERIOR,	  TWO_FLOAT_PARAM,   SAVE_TOKEN_NUM, NEED_TWO_FLOAT_1);
+    fsm_table (BLOCK_INTERIOR,	  STRING_PARAM,      SAVE_TOKEN_NUM, NEED_STRING);
     fsm_table (BLOCK_INTERIOR,	  VECTOR_INT_PARAM,  SAVE_TOKEN_NUM, NEED_VECTOR_INT);
     fsm_table (BLOCK_INTERIOR,	  VECTOR_FLOAT_PARAM,SAVE_TOKEN_NUM, NEED_VECTOR_FLOAT);
     fsm_table (BLOCK_INTERIOR,	  VECTOR_CHAR_PARAM, CLEAR_FREQS,    NEED_VECTOR_CHAR);
@@ -93,6 +94,8 @@ create_fsm ()
     fsm_table (NEED_TWO_FLOAT_2,  FLOAT,             INSERT_V_PAR,   BLOCK_INTERIOR);
     fsm_table (NEED_TWO_FLOAT_2,  INTEGER,           INSERT_V_PAR,   BLOCK_INTERIOR);
 
+    fsm_table (NEED_STRING,       MANY_CHAR,         INSERT_STRING,  BLOCK_INTERIOR);
+
     fsm_table (NEED_VECTOR_INT,   INTEGER,           INSERT_V_PAR,   NEED_VECTOR_INT);
     fsm_table (NEED_VECTOR_INT,	  MATCH_ALL,         POP_TOKEN,      BLOCK_INTERIOR);  
 
