@@ -258,6 +258,8 @@ int parser ()
                        cb_ptr -> pc_amp_hcode = float_values[tval];
                    else if (toknum == FMATCH_BW_PCT_)
                        cb_ptr -> fmatch_bw_pct = float_values[tval];
+                   else if (toknum == MBD_ANCHOR_)
+                       cb_ptr -> mbd_anchor = tval;
                break;
 
 
