@@ -4,6 +4,9 @@
 
 #include "mk4_util.h"
 
+char progname[]= "testutil";
+int msglev = 2;
+
 main (argc, argv)
 int argc;
 char *argv[];
